<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Tray</source>
        <translation>Panel</translation>
    </message>
    <message>
        <source>Desktop Docking</source>
        <translation>Ukotvení na ploše</translation>
    </message>
    <message>
        <source>Horizontal position</source>
        <translation>Vodorovné umístění</translation>
    </message>
    <message>
        <source>Vertical position</source>
        <translation>Svislé umístění</translation>
    </message>
    <message>
        <source>Transparent</source>
        <translation>Průhledné</translation>
    </message>
    <message>
        <source>Background color</source>
        <translation>Barva pozadí</translation>
    </message>
    <message>
        <source>Enable Move entry in docklet&apos;s menu</source>
        <translation>Povolit v ukotvovací nabídce položku pro přesun</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Přesunout</translation>
    </message>
    <message>
        <source>Enable icon moving on desktop. After pressing move cursor over docking icon and then move. Press any mouse key when the icon is in right place.</source>
        <translation>Povolit přesun ikony po ploše. Stisknutí přesunovacího ukazovátka nad ukotvovací ikonou a potom přesunout. Stiskněte jakékoli tlačítko myši, až ikona bude na správném místě.</translation>
    </message>
    <message>
        <source>Buddies list</source>
        <translation>Seznam kamarádů</translation>
    </message>
</context>
<context>
    <name>DesktopDock</name>
    <message>
        <source>Move</source>
        <translation>Přesunout</translation>
    </message>
</context>
</TS>